@@ -1,5 +1,5 @@
 extract.level <-
-function(var,infile,outfile,level=1){
+function(var,infile,outfile,level=1,nc34=3){
 
   start.time <- Sys.time()
 
@@ -53,17 +53,26 @@ function(var,infile,outfile,level=1){
   # get information about dimensions
 
   dimnames <- names(id$dim)
+  dimnames <- dimnames[!dimnames %in% "nb2"] # this can cause trouble
 
   # check standard_names of dimensions
-  for (i in 1:length(dimnames)){
-	  sn <- ncatt_get(id,dimnames[i],"standard_name")
-	  if (length(sn)>0){
-	    sn <- sn$value
-	    if (sn=="longitude")(lon_name <- dimnames[i])
-	    if (sn=="latitude")(lat_name <- dimnames[i])
-	    if (sn=="time")(t_name <- dimnames[i])
-	  }
-  }
+    for (i in 1:length(dimnames)){
+	    sn <- ncatt_get(id,dimnames[i],"standard_name")
+	    ln <- ncatt_get(id,dimnames[i],"long_name")
+	    if (sn$hasatt){
+	      sn <- sn$value
+	      if (sn %in% c("longitude","Longitude","Lon","lon"))(lon_name <- dimnames[i])
+	      if (sn %in% c("latitude","Latitude","Lat","lat"))(lat_name <- dimnames[i])
+	      if (sn=="time"|sn=="Time")(t_name <- dimnames[i])
+	    } else {
+	        if (ln$hasatt){
+	          ln <- ln$value
+	          if (ln %in% c("longitude","Longitude","Lon","lon"))(lon_name <- dimnames[i])
+	          if (ln %in% c("latitude","Latitude","Lat","lat"))(lat_name <- dimnames[i])
+	          if (ln=="time"|ln=="Time")(t_name <- dimnames[i])
+	        }
+	    }
+    }
 
   for (i in 1:length(dimnames)){
     if (t_name %in% dimnames){
@@ -142,6 +151,16 @@ function(var,infile,outfile,level=1){
 # create netcdf
 
   cat("create netcdf", "\n")
+
+  # NetCDF format 3 or 4
+  
+  if (nc34==4){
+    nc_format <- as.logical(1)
+    compression = 4
+  } else {
+    nc_format <- as.logical(0)
+    compression = NA
+  }
   
   for (i in 1:loop){
     
@@ -171,20 +190,19 @@ function(var,infile,outfile,level=1){
       tb <- ncdim_def(name="nb2",units=nb2_units,vals=nb2)
     }
 
-    var1 <- ncvar_def(name=var,units=v_units,dim=list(x,y,t),prec=var_prec)
+    var1 <- ncvar_def(name=var,units=v_units,dim=list(x,y,t),missval=v_missing_value,
+                      prec=var_prec,compression=compression)
 
     if ("time_bnds" %in% varnames){
       var2 <- ncvar_def(name="time_bnds",units="1",dim=list(tb,t),prec="double")
       vars <- list(var1,var2)
-      ncnew <- nc_create(outfile1,vars)
+      ncnew <- nc_create(outfile,vars,force_v4=nc_format)
 
       ncvar_put(ncnew,var1,data1)
       ncvar_put(ncnew,var2,tbnds1)
 
       ncatt_put(ncnew,var,"standard_name",v_standard_name,prec="text")
       ncatt_put(ncnew,var,"long_name",v_long_name,prec="text")
-      ncatt_put(ncnew,var,"_FillValue",v__FillValue,prec=var_prec)
-      ncatt_put(ncnew,var,"missing_value",v_missing_value,prec=var_prec)
 
       ncatt_put(ncnew,"time","standard_name",t_standard_name,prec="text")
       ncatt_put(ncnew,"time","calendar",t_calendar,prec="text")
@@ -202,14 +220,12 @@ function(var,infile,outfile,level=1){
 
     } else {
       vars <- list(var1)
-      ncnew <- nc_create(outfile1,vars)
+      ncnew <- nc_create(outfile,vars,force_v4=nc_format)
 
       ncvar_put(ncnew,var1,data1)
 
       ncatt_put(ncnew,var,"standard_name",v_standard_name,prec="text")
       ncatt_put(ncnew,var,"long_name",v_long_name,prec="text")
-      ncatt_put(ncnew,var,"_FillValue",v__FillValue,prec=var_prec)
-      ncatt_put(ncnew,var,"missing_value",v_missing_value,prec=var_prec)
 
       ncatt_put(ncnew,"time","standard_name",t_standard_name,prec="text")
       ncatt_put(ncnew,"time","calendar",t_calendar,prec="text")
@@ -230,7 +246,7 @@ function(var,infile,outfile,level=1){
     
   } # end for loop
 
-end.time <- Sys.time()
-cat("processing time: ",round(as.numeric(end.time-start.time,units="secs"),digits=2)," s", sep="","\n")
+  end.time <- Sys.time()
+  cat("processing time: ",round(as.numeric(end.time-start.time,units="secs"),digits=2)," s", sep="","\n")
   } # endif filecheck
 }
