@@ -1,5 +1,5 @@
 muldpm <-
-function(var,infile,outfile){
+function(var,infile,outfile,nc34=3){
 
   start.time <- Sys.time()
 
@@ -53,25 +53,34 @@ function(var,infile,outfile){
   # get information about dimensions
 
   dimnames <- names(id$dim)
+  dimnames <- dimnames[!dimnames %in% "nb2"] # this can cause trouble
 
     # check standard_names of dimensions
-      for (i in 1:length(dimnames)){
-	sn <- ncatt_get(id,dimnames[i],"standard_name")
-	if (length(sn)>0){
-	  sn <- sn$value
-	  if (sn=="longitude")(lon_name <- dimnames[i])
-	  if (sn=="latitude")(lat_name <- dimnames[i])
-	  if (sn=="time")(t_name <- dimnames[i])
-	}
-      }
+    for (i in 1:length(dimnames)){
+	    sn <- ncatt_get(id,dimnames[i],"standard_name")
+	    ln <- ncatt_get(id,dimnames[i],"long_name")
+	    if (sn$hasatt){
+	      sn <- sn$value
+	      if (sn %in% c("longitude","Longitude","Lon","lon"))(lon_name <- dimnames[i])
+	      if (sn %in% c("latitude","Latitude","Lat","lat"))(lat_name <- dimnames[i])
+	      if (sn=="time"|sn=="Time")(t_name <- dimnames[i])
+	    } else {
+	        if (ln$hasatt){
+	          ln <- ln$value
+	          if (ln %in% c("longitude","Longitude","Lon","lon"))(lon_name <- dimnames[i])
+	          if (ln %in% c("latitude","Latitude","Lat","lat"))(lat_name <- dimnames[i])
+	          if (ln=="time"|ln=="Time")(t_name <- dimnames[i])
+	        }
+	    }
+    }
 
   for (i in 1:length(dimnames)){
     if (t_name %in% dimnames){
       attnames <- names(id$dim[[i]])
       if ("units" %in% attnames){
-	t_units <- ncatt_get(id,t_name,"units")$value}
+	      t_units <- ncatt_get(id,t_name,"units")$value}
       if ("calendar" %in% attnames){
-	t_calendar <- ncatt_get(id,t_name,"calendar")$value}
+	      t_calendar <- ncatt_get(id,t_name,"calendar")$value}
     }
   }
 
@@ -83,7 +92,7 @@ function(var,infile,outfile){
     for (i in 1:6){
       att_dum <- ncatt_get(id,var,att_list[i])
       if (att_dum$hasatt){
-	assign(v_att_list[i],att_dum$value)}
+	      assign(v_att_list[i],att_dum$value)}
     }
 
       # get details of file
@@ -124,6 +133,16 @@ function(var,infile,outfile){
 
   cat("create netcdf", "\n")
 
+  # NetCDF format 3 or 4
+  
+  if (nc34==4){
+    nc_format <- as.logical(1)
+    compression = 4
+  } else {
+    nc_format <- as.logical(0)
+    compression = NA
+  }
+
     target[is.na(target)] <- v_missing_value
 
     nb2 <- c(0,1)
@@ -135,20 +154,19 @@ function(var,infile,outfile){
       tb <- ncdim_def(name="nb2",units="1",vals=nb2)
     }
 
-    var1 <- ncvar_def(name=var,units=v_units,dim=list(x,y,t),prec=var_prec)
+    var1 <- ncvar_def(name=var,units=v_units,dim=list(x,y,t),missval=v_missing_value,
+                      prec=var_prec,compression=compression)
 
     if ("time_bnds" %in% varnames){
       var2 <- ncvar_def(name="time_bnds",units="1",dim=list(tb,t),prec="double")
       vars <- list(var1,var2)
-      ncnew <- nc_create(outfile,vars)
+      ncnew <- nc_create(outfile,vars,force_v4=nc_format)
 
       ncvar_put(ncnew,var1,target)
       ncvar_put(ncnew,var2,time_bnds)
 
       ncatt_put(ncnew,var,"standard_name",v_standard_name,prec="text")
       ncatt_put(ncnew,var,"long_name",v_long_name,prec="text")
-      ncatt_put(ncnew,var,"_FillValue",v__FillValue,prec=var_prec)
-      ncatt_put(ncnew,var,"missing_value",v_missing_value,prec=var_prec)
 
       ncatt_put(ncnew,"time","standard_name",t_standard_name,prec="text")
       ncatt_put(ncnew,"time","calendar",t_calendar,prec="text")
@@ -166,14 +184,12 @@ function(var,infile,outfile){
 
     } else {
       vars <- list(var1)
-      ncnew <- nc_create(outfile,vars)
+      ncnew <- nc_create(outfile,vars,force_v4=nc_format)
 
       ncvar_put(ncnew,var1,target)
 
       ncatt_put(ncnew,var,"standard_name",v_standard_name,prec="text")
       ncatt_put(ncnew,var,"long_name",v_long_name,prec="text")
-      ncatt_put(ncnew,var,"_FillValue",v__FillValue,prec=var_prec)
-      ncatt_put(ncnew,var,"missing_value",v_missing_value,prec=var_prec)
 
       ncatt_put(ncnew,"time","standard_name",t_standard_name,prec="text")
       ncatt_put(ncnew,"time","calendar",t_calendar,prec="text")
@@ -196,10 +212,10 @@ function(var,infile,outfile){
       count <- 1
   
       for (i in 1:length(time1)){
-	# get days per month
-	leap = 0
-	if (years[i] %% 4 == 0 & (years[i] %% 100 != 0 | years[i] %% 400 == 0)){leap = 1}
-	dpm <- (switch(mon[i],
+	    # get days per month
+	      leap = 0
+	      if (years[i] %% 4 == 0 & (years[i] %% 100 != 0 | years[i] %% 400 == 0)){leap = 1}
+	      dpm <- (switch(mon[i],
          '01' = 31,
          '02' = 28 + leap,
          '03' = 31,
@@ -213,21 +229,21 @@ function(var,infile,outfile){
          '11' = 30,
          '12' = 31))
 
-	  dum_dat <- ncvar_get(id,var,start=c(1,1,i),count=c(-1,-1,1))
-	  cat("\r","multiply timestep ",i," of ",length(time1),sep="")
-	  dum_dat <- dum_dat*dpm
-	  dum_dat[is.na(dum_dat)] <- v_missing_value
-	  ncvar_put(ncnew,var1,dum_dat,start=c(1,1,count),count=c(-1,-1,1))
-	  ncvar_put(ncnew,t,time1[i], start=count, count=1)
-	  if ("time_bnds" %in% varnames){
-	    ncvar_put(ncnew,var2,tbnds1[,i],start=c(1,count),count=c(-1,1))
-	  }
-	  count <- count+1
+	      dum_dat <- ncvar_get(id,var,start=c(1,1,i),count=c(-1,-1,1))
+	      cat("\r","multiply timestep ",i," of ",length(time1),sep="")
+	      dum_dat <- dum_dat*dpm
+	      dum_dat[is.na(dum_dat)] <- v_missing_value
+	      ncvar_put(ncnew,var1,dum_dat,start=c(1,1,count),count=c(-1,-1,1))
+	      ncvar_put(ncnew,t,time1[i], start=count, count=1)
+	      if ("time_bnds" %in% varnames){
+	        ncvar_put(ncnew,var2,tbnds1[,i],start=c(1,count),count=c(-1,1))
+	      }
+	      count <- count+1
       }
       nc_close(id)
       nc_close(ncnew)
 
-end.time <- Sys.time()
-cat("\n","processing time: ",round(as.numeric(end.time-start.time,units="secs"),digits=2)," s",sep="", "\n")
+  end.time <- Sys.time()
+  cat("\n","processing time: ",round(as.numeric(end.time-start.time,units="secs"),digits=2)," s",sep="", "\n")
   } # endif filecheck
 }
