@@ -1,5 +1,5 @@
 year.anomaly <-
-function(var,infile,outfile){
+function(var,infile,outfile,nc34=3){
 
   start.time <- Sys.time()
 
@@ -57,17 +57,26 @@ function(var,infile,outfile){
   # get information about dimensions
 
   dimnames <- names(id$dim)
+  dimnames <- dimnames[!dimnames %in% "nb2"] # this can cause trouble
 
     # check standard_names of dimensions
-      for (i in 1:length(dimnames)){
-	sn <- ncatt_get(id,dimnames[i],"standard_name")
-	if (length(sn)>0){
-	  sn <- sn$value
-	  if (sn=="longitude")(lon_name <- dimnames[i])
-	  if (sn=="latitude")(lat_name <- dimnames[i])
-	  if (sn=="time")(t_name <- dimnames[i])
-	}
-      }
+    for (i in 1:length(dimnames)){
+	    sn <- ncatt_get(id,dimnames[i],"standard_name")
+	    ln <- ncatt_get(id,dimnames[i],"long_name")
+	    if (sn$hasatt){
+	      sn <- sn$value
+	      if (sn %in% c("longitude","Longitude","Lon","lon"))(lon_name <- dimnames[i])
+	      if (sn %in% c("latitude","Latitude","Lat","lat"))(lat_name <- dimnames[i])
+	      if (sn=="time"|sn=="Time")(t_name <- dimnames[i])
+	    } else {
+	        if (ln$hasatt){
+	          ln <- ln$value
+	          if (ln %in% c("longitude","Longitude","Lon","lon"))(lon_name <- dimnames[i])
+	          if (ln %in% c("latitude","Latitude","Lat","lat"))(lat_name <- dimnames[i])
+	          if (ln=="time"|ln=="Time")(t_name <- dimnames[i])
+	        }
+	    }
+    }
 
   for (i in 1:length(dimnames)){
     if (t_name %in% dimnames){
@@ -126,10 +135,35 @@ function(var,infile,outfile){
       nc_close(id)
       stop(cat(paste("Variable ",var," not found! File contains: ",varnames,sep="")),"\n")}
 
-  if (v__FillValue == "undefined"){ 
-    v__FillValue = v_missing_value}
-  if (v_missing_value == "undefined"){ 
-    v_missing_value = v__FillValue} 
+      # calculate field maximum 
+	
+	 maxval <- array(NA,dim=c(3))
+	 if (time_len>=3){
+	   samp <- sample(c(1:time_len),3)
+	 } else {
+	   samp <- 1
+	 }
+	 count <- 1
+	 for (i in samp){
+	   data1 <- ncvar_get(id,var,start=c(1,1,i),count=c(-1,-1,1))
+	   maxval[count] <- max(data1,na.rm=T)
+	   count <- count+1
+	 }
+ 	
+	 if (v__FillValue == "undefined"){ 
+	     v__FillValue = v_missing_value}
+	 if (v_missing_value == "undefined"){ 
+	     v_missing_value = v__FillValue}
+	
+	  # check max to avoid problems with fillvalue
+	
+	  fval <- c(-99,-999,-9999)
+	  maxval <- max(maxval,na.rm=TRUE)
+	  maxval <- abs(maxval)*(-2.5)
+	  dum <- min(which(fval<maxval,arr.ind=TRUE),na.rm=TRUE)
+	  mval <- fval[dum]
+	  v__FillValue = mval
+	  v_missing_value = mval   
 
   # check data dimensions and calculate climatology 
   
@@ -185,6 +219,15 @@ function(var,infile,outfile){
 # create netcdf
 
   cat("create netcdf", "\n")
+  # NetCDF format 3 or 4
+  
+  if (nc34==4){
+    nc_format <- as.logical(1)
+    compression = 4
+  } else {
+    nc_format <- as.logical(0)
+    compression = NA
+  }
 
     target[is.na(target)] <- v_missing_value
 
@@ -196,18 +239,17 @@ function(var,infile,outfile){
     t <- ncdim_def(name="time",units=t_units,vals=times,unlim=TRUE)
     tb <- ncdim_def(name="nb2",units="1",vals=nb2)
 
-    var1 <- ncvar_def(name=var,units=v_units,dim=list(x,y,t),prec=var_prec)
+    var1 <- ncvar_def(name=var,units=v_units,dim=list(x,y,t),missval=v_missing_value,
+                      prec=var_prec,compression=compression)
     var2 <- ncvar_def(name="time_bnds",units="1",dim=list(tb,t),prec="double")
     vars <- list(var1,var2)
-    ncnew <- nc_create(outfile,vars)
+    ncnew <- nc_create(outfile,vars,force_v4=nc_format)
 
     ncvar_put(ncnew,var1,target)
     ncvar_put(ncnew,var2,time_bnds)
 
     ncatt_put(ncnew,var,"standard_name",v_standard_name,prec="text")
     ncatt_put(ncnew,var,"long_name",v_long_name,prec="text")
-    ncatt_put(ncnew,var,"_FillValue",v__FillValue,prec=var_prec)
-    ncatt_put(ncnew,var,"missing_value",v_missing_value,prec=var_prec)
 
     ncatt_put(ncnew,"time","standard_name",t_standard_name,prec="text")
     ncatt_put(ncnew,"time","calendar",t_calendar,prec="text")
@@ -243,7 +285,7 @@ function(var,infile,outfile){
 
  nc_close(ncnew)
 
-end.time <- Sys.time()
-cat("\n","processing time: ",round(as.numeric(end.time-start.time,units="secs"),digits=2)," s",sep="", "\n")
+  end.time <- Sys.time()
+  cat("\n","processing time: ",round(as.numeric(end.time-start.time,units="secs"),digits=2)," s",sep="", "\n")
   } # endif filecheck
 }
