@@ -1,5 +1,5 @@
 yseasmax <-
-function(var,infile,outfile){
+function(var,infile,outfile,nc34=3){
 
   start.time <- Sys.time()
 
@@ -53,15 +53,24 @@ function(var,infile,outfile){
   # get information about dimensions
 
   dimnames <- names(id$dim)
+  dimnames <- dimnames[!dimnames %in% "nb2"] # this can cause trouble
 
-    # check standard_names of dimensions
+   # check standard_names of dimensions
     for (i in 1:length(dimnames)){
 	    sn <- ncatt_get(id,dimnames[i],"standard_name")
-	    if (length(sn)>0){
+	    ln <- ncatt_get(id,dimnames[i],"long_name")
+	    if (sn$hasatt){
 	      sn <- sn$value
-	      if (sn=="longitude")(lon_name <- dimnames[i])
-	      if (sn=="latitude")(lat_name <- dimnames[i])
-	      if (sn=="time")(t_name <- dimnames[i])
+	      if (sn %in% c("longitude","Longitude","Lon","lon"))(lon_name <- dimnames[i])
+	      if (sn %in% c("latitude","Latitude","Lat","lat"))(lat_name <- dimnames[i])
+	      if (sn=="time"|sn=="Time")(t_name <- dimnames[i])
+	    } else {
+	        if (ln$hasatt){
+	          ln <- ln$value
+	          if (ln %in% c("longitude","Longitude","Lon","lon"))(lon_name <- dimnames[i])
+	          if (ln %in% c("latitude","Latitude","Lat","lat"))(lat_name <- dimnames[i])
+	          if (ln=="time"|ln=="Time")(t_name <- dimnames[i])
+	        }
 	    }
     }
 
@@ -148,7 +157,15 @@ function(var,infile,outfile){
 
 # create netcdf
 
-  cat("create netcdf", "\n")
+  cat("create netcdf", "\n")  # NetCDF format 3 or 4
+  
+  if (nc34==4){
+    nc_format <- as.logical(1)
+    compression = 4
+  } else {
+    nc_format <- as.logical(0)
+    compression = NA
+  }
 
     target[is.na(target)] <- v_missing_value
     nb2 <- c(0,1)
@@ -158,18 +175,17 @@ function(var,infile,outfile){
     t <- ncdim_def(name="time",units=t_units,vals=0,unlim=TRUE)
     tb <- ncdim_def(name="nb2",units="1",vals=nb2)
 
-    var1 <- ncvar_def(name=var,units=v_units,dim=list(x,y,t),prec=var_prec)
+    var1 <- ncvar_def(name=var,units=v_units,dim=list(x,y,t),missval=v_missing_value,
+                      prec=var_prec,compression=compression)
     var2 <- ncvar_def(name="time_bnds",units="1",dim=list(tb,t),prec="double")
     vars <- list(var1,var2)
-    ncnew <- nc_create(outfile,vars)
+    ncnew <- nc_create(outfile,vars,force_v4=nc_format)
 
     ncvar_put(ncnew,var1,target)
     ncvar_put(ncnew,var2,tbnds)
 
     ncatt_put(ncnew,var,"standard_name",v_standard_name,prec="text")
     ncatt_put(ncnew,var,"long_name",v_long_name,prec="text")
-    ncatt_put(ncnew,var,"_FillValue",v__FillValue,prec=var_prec)
-    ncatt_put(ncnew,var,"missing_value",v_missing_value,prec=var_prec)
 
     ncatt_put(ncnew,"time","standard_name",t_standard_name,prec="text")
     ncatt_put(ncnew,"time","calendar",t_calendar,prec="text")
@@ -209,14 +225,14 @@ function(var,infile,outfile){
 	  ncvar_put(ncnew,t,tdum,start=count,count=1)
 	  ncvar_put(ncnew,var2,tbnds,start=c(1,count),count=c(-1,1))
 	  count <- count+1
-	}
+	} else {cat("75% of monthly data have to be available - that's not the case","\n")}
      }
 
  nc_close(id)
 
  nc_close(ncnew)
 
-end.time <- Sys.time()
-cat("\n","processing time: ",round(as.numeric(end.time-start.time,units="secs"),digits=2)," s",sep="", "\n")
+  end.time <- Sys.time()
+  cat("\n","processing time: ",round(as.numeric(end.time-start.time,units="secs"),digits=2)," s",sep="", "\n")
   } # endif filecheck
 }
